==> lxqt-session-0.14.0.tar.xz: lxqt-session-0.14.0/lxqt-leave/translations/lxqt-leave_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Que doit faire l&apos;ordinateur ?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="51"/>
        <source>Logout</source>
        <translation>Déconnexion</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="66"/>
        <source>Lock screen</source>
        <translation>Verrouiller l&apos;écran</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="61"/>
        <source>Suspend</source>
        <translation>Suspendre</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="74"/>
        <source>Hibernate</source>
        <translation>Hiberner</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="56"/>
        <source>Shutdown</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="69"/>
        <source>Reboot</source>
        <translation>Redémarrer</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Logout.</source>
        <translation>Déconnexion.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Lockscreen.</source>
        <translation>Verrouillage de l&apos;écran.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Suspend.</source>
        <translation>Suspendre.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Hibernate.</source>
        <translation>Hibernation.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Shutdown.</source>
        <translation>Arrêt.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Reboot.</source>
        <translation>Redémarrage.</translation>
    </message>
</context>
</TS>

==> lxqt-session-0.15.0.tar.xz: lxqt-session-0.15.0/lxqt-leave/translations/lxqt-leave_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LeaveDialog</name>
    <message>
        <location filename="../leavedialog.ui" line="20"/>
        <source>Leave</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="51"/>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
    <message>
        <location filename="../leavedialog.ui" line="71"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;What do you want the computer to do?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:12pt;&quot;&gt;Que voulez-vous que l&apos;ordinateur fasse ?&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="51"/>
        <source>Logout</source>
        <translation>Déconnexion</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="66"/>
        <source>Lock screen</source>
        <translation>Verrouiller l&apos;écran</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="61"/>
        <source>Suspend</source>
        <translation>Suspendre</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="74"/>
        <source>Hibernate</source>
        <translation>Hiberner</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="56"/>
        <source>Shutdown</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="../leavedialog.cpp" line="69"/>
        <source>Reboot</source>
        <translation>Redémarrer</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Logout.</source>
        <translation>Déconnexion.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>Lockscreen.</source>
        <translation>Verrouillage de l&apos;écran.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="64"/>
        <source>Suspend.</source>
        <translation>Suspendre.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="67"/>
        <source>Hibernate.</source>
        <translation>Hibernation.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="70"/>
        <source>Shutdown.</source>
        <translation>Arrêt.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <source>Reboot.</source>
        <translation>Redémarrage.</translation>
    </message>
</context>
</TS>
